@@ -10,8 +10,7 @@ public:
   PqDataFrame(PqResultSource* result_source,
               const std::vector<std::string>& names,
               const int n_max_,
-              const std::vector<DATA_TYPE>& types,
-              std::vector<Oid> oids);
+              const std::vector<DATA_TYPE>& types);
   ~PqDataFrame();
 };
 
